@@ -74,6 +74,7 @@ class MigrationCommand(BaseCommand):
                 self.info('Migration aborted')
                 sys.exit(1)
             self.info('Deleting previously not finished migrations...')
+            self.before_delete_not_finished_migrations(not_finished_migrations)
             not_finished_migrations.delete()
 
     def debug(self, msg):
@@ -303,6 +304,11 @@ class MigrationCommand(BaseCommand):
         """
         obj.save()
 
+    def before_delete_not_finished_migrations(self, not_finished_migrations):
+        """
+        To be overriden in subclasses
+        """
+
     # ----- default filters  -----
 
     def filter_strip(self, value):
