@@ -53,5 +53,9 @@ class MigratedObject(models.Model):
             del self._object_cache  # force object reloading
         self.object_name = unicode(self.object)[:200]
         if hasattr(self.object, 'get_absolute_url'):
-            self.object_url = self.object.get_absolute_url()
+            try:
+                self.object_url = self.object.get_absolute_url()
+            except:
+                # maybe the object is consistent and fails get_absolute_url method
+                self.object_url = 'Error getting URL'
         super(MigratedObject, self).save(*args, **kwargs)
